#
#----------------------------------------------------------------------
#   FramePlot
#----------------------------------------------------------------------
import random as RND
import numpy as NP
import matplotlib.pyplot as PLT
import tkinter as TKI
from matplotlib.backends.backend_tkagg \
    import FigureCanvasTkAgg #, NavigationToolbar2Tk
#
import Define as DEF
import Task as TSK
#
#----------------------------------------------------------------------
class CFramePlot(TKI.Frame):
    #
    def __init__(self, parent):
        super().__init__(parent)
        self.Parent = parent
        #self.Figure = PLT.figure(figsize=(8, 8), dpi=100)
        self.Figure = PLT.figure(figsize=(18, 12), dpi=100)
        self.Axis = PLT.axes(projection='3d')
        #
        self.Canvas = FigureCanvasTkAgg(self.Figure, master=self.Parent)
        #self.Toolbar = NavigationToolbar2Tk(self.Canvas, window)
        self.Canvas.get_tk_widget().grid(row=0, column=0)
        #
        self.TimePeriod = DEF.TIMEPERIOD_IDLE_MS
        self.XL = 0.0 #xl
        self.XH = 20.0 #xh
        self.YL = 0.0 #yl
        self.YH = 20.0 #yh
        self.ZL = -10.0 #zl
        self.ZH = 10.0 #zh
        self.Elevation = 30.0
        self.Azimuth = 30.0
        self.Axis.set_xlim([self.XL, self.XH])
        self.Axis.set_ylim([self.YL, self.YH])
        self.Axis.set_zlim([self.ZL, self.ZH])
        self.VX = []
        self.VY = []
        self.VZ = []
        self.EventTriggerPlot = TSK.CEvent()
        self.EventTriggerPlot.Set()
        self.RefreshPeriodic()
        self.EventTriggerPlot.Clear()
        #
        self.InitScale()
        #
    #
    def SetTimePeriodic(self, data):
        self.TimePeriod = data
    #
    def SetVX(self, data):
        self.VX = data
    def SetVY(self, data):
        self.VY = data
    def SetVZ(self, data):
        self.VZ = data
    #
    def SetXL(self, data):
        self.XL = data
    def SetXH(self, data):
        self.XH = data
    def SetYL(self, data):
        self.YL = data
    def SetYH(self, data):
        self.YH = data
    def SetZL(self, data):
        self.ZL = data
    def SetZH(self, data):
        self.ZH = data
    #
    def SetElevation(self, data):
        self.Elevation = data
    def SetAzimuth(self, data):
        self.Azimuth = data
    #
    def InitScale(self):
        self.Axis.cla()
        self.Axis.grid("both")
        self.Axis.axis('auto') #'equal')
        self.Axis.set_aspect('auto', 'box')#'equal', 'box')
        self.Axis.set_xlabel("X [mm]")
        self.Axis.set_ylabel("Y [mm]")
        self.Axis.set_zlabel("Z [mm]")
        #
        self.Axis.set_xlim([self.XL, self.XH])
        self.Axis.set_ylim([self.YL, self.YH])
        self.Axis.set_zlim([self.ZL, self.ZH])
        #
        self.Axis.view_init(elev=self.Elevation, azim=self.Azimuth)
    #
    def Rescale(self):
        self.InitScale()
        return
    #
    def TriggerPlot(self):
        self.EventTriggerPlot.Set()
        self.EventTriggerPlot.Clear()
        return
    #
    def RefreshPeriodic(self):
        if (0 < len(self.VX)):
            self.InitScale()
            self.Axis.plot3D(self.VX, self.VY, self.VZ,
                             linestyle='solid', color='#ff8888', linewidth=4.0)
            self.Canvas.draw()
            self.Canvas.flush_events()
        self.EventTriggerPlot.Wait()
        self.Parent.after(self.TimePeriod, self.RefreshPeriodic)
        return
    #
    #
#
#
